/*
 * $Id: smsform.ui.h,v 1.6 2006/08/28 14:34:36 pjedryczek Exp $
 */


/****************************************************************************
** ui.h extension file, included from the uic-generated form implementation.
**
** If you want to add, delete, or rename functions or slots, use
** Qt Designer to update this file, preserving your code.
**
** You should not define a constructor or destructor in this file.
** Instead, write your code in functions called init() and destroy().
** These will automatically be called by the form's constructor and
** destructor.
*****************************************************************************/
/****************************************************************************
   QGnokii - an alternative frontend for Gnokii
    Copyright (C) 2006  Piotr Jedryczek

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
**************************************************************************/
#include <qlineedit.h>
#include <stdio.h>
#include <stdlib.h>
#include <qmessagebox.h>
#include <qvalidator.h>
#include <qregexp.h>
#include <qsocketdevice.h>
#include "abform.h"
#include "global.h"
#include "mainform.h"

void smsForm::init()
{
    QRegExp regExp("[+]?[0-9]+");
    toLineEdit->setValidator(new QRegExpValidator(regExp, this));
    scenterLineEdit->setValidator(new QRegExpValidator(regExp, this));
}

void smsForm::sendSMSSlot()
{
    QString telnumber;
    QString scenternumber;
    QString content;
    bool isReport = FALSE;
    bool isSmsc = FALSE;
    char code[CODE_LEN];
    qgnokii_global *global = new qgnokii_global;
   
    if(deliveryReportCheckBox->isChecked())
	isReport = TRUE;
    if(!scenterCheckBox->isChecked())
    {
	isSmsc = TRUE;
	scenternumber = scenterLineEdit->text();
    }
    // Getting data from user
    telnumber = toLineEdit->text();
    content = contentTextEdit->text();
    
    if(global->connectQSocketDevice() != 0)
    {
	QMessageBox::critical(this, "Error", "Can't connect to QGnokiid", QMessageBox::Ok, QMessageBox::NoButton, QMessageBox::NoButton);
	return;
    }
    
    // Sending request to QGnokii daemon
    global->socket->writeBlock(BEGIN_CODE, CODE_LEN);
    global->socket->writeBlock(SENDSMS_CODE, CODE_LEN);
    
    // Sending data to daemon
    global->socket->readBlock(code, CODE_LEN);
    if(strcmp(code, BEGIN_CODE) == 0)
    {
	global->socket->readBlock(code, CODE_LEN);
	if(strcmp(code, SENDSMS_CODE) == 0)
	{
	    global->socket->writeBlock(telnumber, telnumber.length()+1);
	    if(isSmsc == TRUE)
	    {
		global->socket->writeBlock("1", 2);
		global->socket->writeBlock(scenternumber, scenternumber.length()+1);
	    }
	    else
		global->socket->writeBlock("0", 2);
	    if(isReport == TRUE)
		global->socket->writeBlock("1", 2);
	    else
		global->socket->writeBlock("0", 2);
	    global->socket->writeBlock(content, content.length()+1);
	    global->socket->readBlock(code, CODE_LEN);
	    if(strcmp(code, END_CODE) == 0)
		QMessageBox::about(this, "Report", "Message sent");
	    else if(strcmp(code, ERR_CODE) == 0)
		QMessageBox::critical(this, "Error", "Can't send the message", QMessageBox::Ok, QMessageBox::NoButton, QMessageBox::NoButton);
	    else
		QMessageBox::critical(this, "Unknown error 3", "Can't send the message", QMessageBox::Ok, QMessageBox::NoButton, QMessageBox::NoButton);
	}
	else
	    QMessageBox::critical(this, "Unknown error 2 ", "Can't send the message", QMessageBox::Ok, QMessageBox::NoButton, QMessageBox::NoButton);
    }
    else
	QMessageBox::critical(this, "Unknown error 1", "Can't send the message", QMessageBox::Ok, QMessageBox::NoButton, QMessageBox::NoButton);
    
    // Disconnecting from daemon
    delete(global);
    
}


void smsForm::enableSendButton()
{
    sendButton->setEnabled((toLineEdit->hasAcceptableInput() && scenterLineEdit->hasAcceptableInput()) || (toLineEdit->hasAcceptableInput() && scenterCheckBox->isChecked()));   
}


void smsForm::saveScenterSlot()
{
    FILE *fp;
    char *scenterfn = new char;
    
     // Get $HOME
    scenterfn = getenv("HOME");
    
    
    // Where the data file is?
    strcat(scenterfn, "/.qgnokii/scenter");

    if((fp = fopen(scenterfn, "w")) == NULL)
    {
	QMessageBox::critical(this, "Error", "Can't open SMS center configuration file", QMessageBox::Ok, QMessageBox::NoButton, QMessageBox::NoButton);
	return;
    }
    if((fputs(scenterLineEdit->text(), fp)) == EOF)
    {
	QMessageBox::critical(this, "Error", "Can't write to SMS center configuration file", QMessageBox::Ok, QMessageBox::NoButton, QMessageBox::NoButton);
	return;
    }
    fclose(fp);
}


void smsForm::readScenterSlot()
{
    FILE *fp;
    char scenternumber[2048];
    char scenterfn[1024];
    char *homedir = new char;
    
    // Get $HOME
    homedir = getenv("HOME");
    
    // Where scenter conf file is?
    strcpy(scenterfn, homedir);
    strcat(scenterfn, "/.qgnokii/scenter");
    if((fp = fopen(scenterfn, "r")) == NULL)
    {
	QMessageBox::critical(this, "Error", "Can't open SMS center configuration file", QMessageBox::Ok, QMessageBox::NoButton, QMessageBox::NoButton);
	return;
    }
    if((fgets(scenternumber, sizeof(scenternumber), fp)) == NULL)
    {
	QMessageBox::critical(this, "Error", "Can't read from SMS center configuration file", QMessageBox::Ok, QMessageBox::NoButton, QMessageBox::NoButton);
	return;
    }
    else
	scenterLineEdit->setText(scenternumber);
    fclose(fp);
}


void smsForm::checkContentLengthSlot()
{
    int length;
    char lengthstr[1024];
    char text[1024];
    
   length = contentTextEdit->length();
   if(length > 160)
   {
       QMessageBox::warning(this, "Warning", "Maximum SMS size exceeded", QMessageBox::Ok, QMessageBox::NoButton, QMessageBox::NoButton);
   }
   sprintf(lengthstr, "%d", length);
   strcpy(text, lengthstr);
   strcat(text, "/160");
   sizeValueLabel->setText(text);  
}


void smsForm::changeScenterStateSlot()
{
    if(scenterCheckBox->isChecked())
	scenterLineEdit->setDisabled(TRUE);
    else
	scenterLineEdit->setDisabled(FALSE);
}
